@@ -1,4 +1,4 @@
-from fbprophet.plot import plot_plotly, plot_components_plotly
+from prophet.plot import plot_plotly, plot_components_plotly
 
 
 def plotly_plot(model, forecast, **kwargs):
